<?php
/**
 * Helpers
 *
 * @package   WP Grid Builder - Multilingual
 * @author    Loïc Blascos
 * @copyright 2019-2020 Loïc Blascos
 */

namespace WP_Grid_Builder_Multilingual\Includes;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Helpers
 *
 * @class WP_Grid_Builder_Multilingual\Includes\Helpers
 * @since 1.0.0
 */
trait Helpers {

	/**
	 * Get current language from Polylang or WPML
	 *
	 * @access public
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function get_current_language() {

		return $this->wpml_current_language() ?: $this->pll_current_language();

	}

	/**
	 * Get default language from Polylang or WPML
	 *
	 * @access public
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function get_default_language() {

		return $this->wpml_default_language() ?: $this->pll_default_language();

	}

	/**
	 * Get current language from WPML
	 *
	 * @access public
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function wpml_current_language() {

		global $sitepress;

		if ( empty( $sitepress ) || ! method_exists( $sitepress, 'get_current_language' ) ) {
			return '';
		}

		return $sitepress->get_current_language();

	}

	/**
	 * Get current language from Polylang
	 *
	 * @access public
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function pll_current_language() {

		if ( ! function_exists( 'pll_current_language' ) ) {
			return '';
		}

		return pll_current_language();

	}

	/**
	 * Get default language from WPML
	 *
	 * @access public
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function wpml_default_language() {

		global $sitepress;

		if ( empty( $sitepress ) || ! method_exists( $sitepress, 'get_default_language' ) ) {
			return '';
		}

		return $sitepress->get_default_language();

	}

	/**
	 * Get default language from Polylang
	 *
	 * @access public
	 * @since 1.0.0
	 *
	 * @return string
	 */
	public function pll_default_language() {

		if ( ! function_exists( 'pll_default_language' ) ) {
			return '';
		}

		return pll_default_language();

	}
}
